
Topsis is a Python package used for MCDM problems which is selection of the best, from a set of alternatives, each of which is evaluated against multiple criteria.

## topsis-3606

This is a project submission for UCS633(Data Analytics and Visualisation) by

Name : **Varinda Rani**

Roll Number : **10703606**

Group : **3CO21**

## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install topsis-3606.

```bash
pip install TOPSIS-3606
```

## Usage

The TOPSIS technique is helpful for decision makers to structure the problems to be solved, conduct analyses, comparisons and ranking of the alternatives. The classical TOPSIS method solves problems in which all decision data are known and represented by crisp numbers.

Following line of code will get you the desired ranking for your dataset.

```python
TOPSIS-3606 PhotogenicFace.csv [1,1,1,1,1] [+,-,+,+,+]
```

## Examplar Dataset

### PhotogenicFace.csv

| ID | EYES | NOSE | FOREHEAD | LIPS  | CHIN |
|----|------|------|----------|-------|------|
| S1 | 0.79 | 0.62 | 1.25     | 60.89 | 11   |
| S2 | 0.66 | 0.44 | 2.89     | 63.07 | 20   |
| S3 | 0.56 | 0.31 | 1.57     | 62.87 | 16   |
| S4 | 0.82 | 0.67 | 2.68     | 70.19 | 16   |
| S5 | 0.75 | 0.56 | 1.3      | 80.39 | 20   |

### Input

```python
TOPSIS-3606 PhotogenicFace.csv [1,1,1,1,1] [+,-,+,+,+]
```
Weights = [1,1,1,1,1]

Impacts = [+,-,+,+,+]

### Result / Output

```bash
Topsis Selection of DATA

Models     | Rank
------------------
1          | 5
------------------
2          | 1
------------------
3          | 3
------------------
4          | 2
------------------
5          | 4
------------------
```

**Make sure your dataset does not contain any categorical data**

## Contributing
Pull requests are welcome. For major changes, please open an issue first to discuss what you would like to change.

Please make sure to update tests as appropriate.

## License
[MIT](https://choosealicense.com/licenses/mit/)